@@ -1,6 +1,6 @@
 /* Yash: yet another shell */
 /* option.c: option settings */
-/* (C) 2007-2011 magicant */
+/* (C) 2007-2012 magicant */
 
 /* This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -825,142 +825,5 @@ int set_builtin_print_restoring_commands(void)
     return Exit_SUCCESS;
 }
 
-#if YASH_ENABLE_HELP
-const char *set_help[] = { Ngt(
-"set - set shell options and positional parameters\n"
-), Ngt(
-"\tset [-abefhmnuvxC] [+abefhmnuvxC] [-o option] [+o option] [--] [arg...]\n"
-"\tset -o\n"
-"\tset +o\n"
-), Ngt(
-"The first form enables or disables the specified shell options and/or sets\n"
-"positional parameters to <arg>s. If no <arg>s are given, the positional\n"
-"parameters are not changed.\n"
-"If no options or <arg>s are given at all, a list of all existing variables\n"
-"is printed. To clear all positional parameters, use `set --'.\n"
-"The second form prints the current settings of the shell options in a human-\n"
-"readable form.\n"
-"The third form prints commands that can be used to restore the current\n"
-"option settings later.\n"
-), (
-"\n"
-), Ngt(
-"Available options are:\n"
-), Ngt(
-" -a --allexport\n"
-"\tAny variable is exported when assigned.\n"
-), Ngt(
-" -b --notify\n"
-"\tWhen the status of a job is changed, it is notified immediately.\n"
-), Ngt(
-" --notifyle\n"
-"\tSimilar to -b, but only notify during line-editing. Ignored if -b is\n"
-"\tset.\n"
-), Ngt(
-" -e --errexit\n"
-"\tExit the shell immediately when any simple command returns a\n"
-"\tnon-zero status.\n"
-), Ngt(
-" +f --glob\n"
-"\tPerform pathname expansion (globbing).\n"
-), Ngt(
-" --caseglob\n"
-"\tPerform pathname expansion case-sensitively.\n"
-), Ngt(
-" --dotglob\n"
-"\tIn pathname expansion, `*' and `?' match a `.' at the beginning of\n"
-"\tthe filename.\n"
-), Ngt(
-" --markdirs\n"
-"\tIn pathname expansion, directory pathnames have a `/' at the ends.\n"
-), Ngt(
-" --extendedglob\n"
-"\tEnable extended pathname expansion.\n"
-), Ngt(
-" --nullglob\n"
-"\tIn pathname expansion, patterns that do not match any pathname are\n"
-"\tremoved from the command line rather than left as is.\n"
-), Ngt(
-" -h --hashondef\n"
-"\tWhen a function is defined, all the commands in the function are\n"
-"\tregistered in the command path cache.\n"
-), Ngt(
-" -m --monitor\n"
-"\tEnable job control. All jobs are run in their own process group.\n"
-"\tWhen the status of a job is changed, the status is reported before\n"
-"\tthe next prompt. This option is enabled by default for an interactive\n"
-"\tshell.\n"
-), Ngt(
-" +n --exec\n"
-"\tExecute commands.\n"
-"\tThis option cannot be disabled in an interactive shell.\n"
-), Ngt(
-" +u --unset\n"
-"\tExpand an undefined variable to an empty string.\n"
-), Ngt(
-" -v --verbose\n"
-"\tEcho each command to the standard error before execution.\n"
-), Ngt(
-" -x --xtrace\n"
-"\tAfter each command line is expanded, the expanded line is printed\n"
-"\tto the standard error.\n"
-), Ngt(
-" +C --clobber\n"
-"\tAllow redirections to overwrite existing files.\n"
-), Ngt(
-" --ignoreeof\n"
-"\tDo not exit when an EOF is entered.\n"
-"\tThis option is effective in an interactive shell only.\n"
-), Ngt(
-" --braceexpand\n"
-"\tEnable brace expansion.\n"
-), Ngt(
-" --curasync, --curbg, --curstop\n"
-"\tA background job becomes the current job when\n"
-"\t   (curasync)  invoked as an asynchronous command\n"
-"\t   (curbg)     resumed by the bg built-in\n"
-"\t   (curstop)   stopped.\n"
-"\t(These options are enabled by default)\n"
-), Ngt(
-" --histspace\n"
-"\tDo not save lines that start with a space in the history.\n"
-), Ngt(
-" --posixly-correct\n"
-"\tMake the shell behave as the POSIX shell.\n"
-), Ngt(
-" --vi\n"
-"\tEnable vi-like editing.\n"
-), Ngt(
-" --emacs\n"
-"\tEnable emacs-like editing.\n"
-), Ngt(
-" --le-convmeta\n"
-"\tTreat 8th bit of input as a meta-key flag (regardless of terminfo).\n"
-), Ngt(
-" --le-noconvmeta\n"
-"\tDo not treat 8th bit of input as a meta-key flag.\n"
-), Ngt(
-" --le-visiblebell\n"
-"\tAlert with a flash rather than a bell.\n"
-), Ngt(
-" --le-promptsp\n"
-"\tMove cursor to beginning of line each time when starting\n"
-"\tline-editing. (enabled by default)\n"
-), Ngt(
-" --le-alwaysrp\n"
-"\tMake the right prompt always visible on the screen.\n"
-), Ngt(
-" --le-compdebug\n"
-"\tPrint debugging information during command line completion.\n"
-), (
-"\n"
-), Ngt(
-"Options can be disabled by using `+' instead of `-'. For example, `set +a'\n"
-"or `set ++allexport' disables the allexport option.\n"
-"Prefixing `no' to a long option also disables the option. For example,\n"
-"`set --nounset' disables the unset option.\n"
-), NULL };
-#endif /* YASH_ENABLE_HELP */
-
 
 /* vim: set ts=8 sts=4 sw=4 noet tw=80: */
