@@ -1,6 +1,6 @@
 /* Yash: yet another shell */
 /* variable.h: deals with shell variables and parameters */
-/* (C) 2007-2011 magicant */
+/* (C) 2007-2012 magicant */
 
 /* This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -158,8 +158,6 @@ extern int popd_builtin(int argc, void **argv)
     __attribute__((nonnull));
 extern int dirs_builtin(int argc, void **argv)
     __attribute__((nonnull));
-extern const char *typeset_help[], *array_help[], *unset_help[], *shift_help[],
-       *getopts_help[], *read_help[], *pushd_help[], *popd_help[], *dirs_help[];
 
 
 #endif /* YASH_VARIABLE_H */
